@@ -21,6 +21,33 @@ Subroutine CHAR_TRIM(string,tfstring,len)
     End Do
 End Subroutine
 
+Subroutine CHAR_TRIM2(string,tfstring,len,len2,len3)
+    Use Iso_C_Binding
+    Character(1,C_char),Intent(In) :: string(*)
+    Character  :: tfstring(*)*(*)
+    Integer(c_int) i,j,k,len,len2,len3
+
+    DO i=1,len2
+    DO j=1,len
+      tfstring(i)(j:j)  = string((i-1)*len3+j)
+    End DO
+    END DO
+End Subroutine
+
+Subroutine CHAR_TRIMC(string,tfstring,len)
+    Use Iso_C_Binding
+    Character(1,C_char),Intent(In) :: string(*)
+    Character*(*)  :: tfstring
+    Integer(c_int) i,len
+
+    Do i=1,len-1
+      tfstring(i:i) = string(i)
+    End Do
+    tfstring(len:len)=CHAR(0)
+End Subroutine
+
+
+
 CHRTRM
 
 puts chartrim
@@ -42,18 +69,27 @@ puts chartrim
         end
         if words[1] == "char" then
           words[1]="CHARACTER(c_char) FUNCTION WR_"
+          corf="  WR_"+fcname[0].upcase+"="
         end
         if words[1] == "int" then
           words[1]="INTEGER(c_int) FUNCTION WR_"
+          corf="  WR_"+fcname[0].upcase+"="
         end
         if words[1] == "logical" then
           words[1]="INTEGER(c_int) FUNCTION WR_"
+          corf="  WR_"+fcname[0].upcase+"="
         end
         if words[1] == "real" then
+          words[1]="REAL(c_float) FUNCTION WR_"
+          corf="  WR_"+fcname[0].upcase+"="
+        end
+        if words[1] == "double" then
           words[1]="REAL(c_double) FUNCTION WR_"
+          corf="  WR_"+fcname[0].upcase+"="
         end
         if words[1] == "void" then
           words[1]="SUBROUTINE WR_"
+          corf="  CALL "
         end
         print(words[1])
         print(fcname[0].upcase)
@@ -79,8 +115,8 @@ puts chartrim
             elsif arr[0] == "integer" then
               arr[0] ="  INTEGER(c_int)"
             elsif arr[0] == "real" then
-                arr[0] ="  REAL(c_double)"
-            elsif arr[0] == "logical" then
+                arr[0] ="  REAL(c_float)"
+            elsif arr[0] == "logical*" then
                 arr[0] ="  INTEGER(c_int)"
             elsif arr[0] == "ftnlen" then
                 arr[0] ="  INTEGER(c_int)"
@@ -115,12 +151,6 @@ puts chartrim
           print("! CV" + VALS[CHAR_VALS[i]] + "CL " + CHAR_LEN[i].to_s + "\n")
           print("  CHARACTER(:,C_char),ALLOCATABLE :: " + VALS[CHAR_VALS[i]]+"A\n")
 
-
-
-
-
-
-
 #          print("  CALL CHAR_TRIM("+VALS[CHAR_VALS[i]]+","+VALS[CHAR_LEN[i]]+");\n")
 
 #         "for(i=" + VAL[CHAR_LEN[i] ;i++
@@ -164,8 +194,14 @@ puts chartrim
         elsif fcname[0][0..-2] == "csgi" then
           print("  AA="+fcname[0][0..-2]+"(C)\n")
         else
-          print("  CALL "+fcname[0][0..-2]+"("+arss[0..-2]+")\n")
+          print(corf+fcname[0][0..-2]+"("+arss[0..-2]+")\n")
         end
+
+        CHAR_LEN.length.times do |i|
+          print("  CALL CHAR_TRIM(" +VALS[CHAR_VALS[i]]+"A,"+VALS[CHAR_VALS[i]]+","+VALS[CHAR_LEN[i]].to_s+")\n")
+        end 
+
+
         print("END\n\n")
       end
     end
